BubblePreference enum

The user's app-level preference for bubbles, from the system notification settings.

Inheritance
Available extensions

Values

none → const BubblePreference

No notifications of this app may bubble.

all → const BubblePreference

All notifications of this app may bubble (subject to per-channel settings, see NotificationChannel.allowBubbles).

selected → const BubblePreference

Only notifications of channels the user selected may bubble.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromNativeValue(int value) BubblePreference
Maps a native NotificationManager bubble preference constant to a BubblePreference.

Constants

values → const List<BubblePreference>
A constant List of the values in this enum, in order of their declaration.