MethodChannelNotificationChannelManager class

An implementation of NotificationChannelManagerPlatform that uses method channels.

Implemented types

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

areBubblesAllowed() → Future<bool>
override
areBubblesEnabled() → Future<bool>
override
createChannel(NotificationChannel notificationChannel) → Future<NotificationChannel>
override
createChannels(List<NotificationChannel> channels) → Future<List<NotificationChannel>>
override
deleteAllChannels() → Future<void>
override
deleteAllGroups() → Future<void>
override
deleteChannel(String channelId) → Future<void>
override
deleteGroup(String channelGroupId) → Future<void>
override
deleteGroups(List<String> channelGroupIds) → Future<void>
override
deleteMultiChannels(List<String> channelIds) → Future<void>
override
getAllChannels() → Future<List<NotificationChannel>>
override
getAllGroups() → Future<List<NotificationChannelGroup>>
override
getBubblePreference() → Future<BubblePreference>
override
getChannel(String channelId, {String? conversationId}) → Future<NotificationChannel?>
override
getGroup(String groupId) → Future<NotificationChannelGroup?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
updateChannel(NotificationChannelUpdate update) → Future<NotificationChannel>
override
updateChannels(List<NotificationChannelUpdate> updates) → Future<List<NotificationChannel>>
override
upsertGroup(NotificationChannelGroup notificationChannelGroup) → Future<NotificationChannelGroup>
override
upsertGroups(List<NotificationChannelGroup> groups) → Future<List<NotificationChannelGroup>>
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited