NotificationChannelUpdate class
The set of fields Android allows changing on an existing channel.
Pass to NotificationChannelManager.updateChannel. Note that Android only ever lowers importance, never raises it, and only while the user hasn't altered the channel's settings.
Constructors
- NotificationChannelUpdate({required String id, required String name, required String description, required NotificationChannelImportance importance})
-
const
Properties
- description → String
-
The new user-visible description.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String
-
The id of the existing channel to update.
final
- importance → NotificationChannelImportance
-
The new importance. Only applied if lower than the current value.
final
- name → String
-
The new user-visible name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override